@@ -1,13 +1,15 @@
 import logging
 from os import mkdir
-from os.path import join, splitext
+from os.path import join
 from shutil import rmtree
 from typing import Any, Iterator, List, Optional, Tuple, Union
 
+from slugify import slugify
+
 from hdx.utilities.base_downloader import BaseDownload, DownloadError
 from hdx.utilities.downloader import Download
 from hdx.utilities.loader import load_json, load_text, load_yaml
-from hdx.utilities.path import get_filename_from_url
+from hdx.utilities.path import get_filename_extension_from_url
 from hdx.utilities.saver import save_json, save_text, save_yaml
 from hdx.utilities.typehint import ListDict, ListTuple
 
@@ -26,6 +28,7 @@ class Retrieve(BaseDownload):
         temp_dir (str): Temporary directory for when data is not needed after downloading
         save (bool): Whether to save downloaded data. Defaults to False.
         use_saved (bool): Whether to use saved data. Defaults to False.
+        prefix (str): Prefix to add to filenames. Defaults to "".
     """
 
     retrievers = dict()
@@ -38,6 +41,7 @@ class Retrieve(BaseDownload):
         temp_dir: str,
         save: bool = False,
         use_saved: bool = False,
+        prefix: str = "",
     ):
         self.downloader = downloader
         self.fallback_dir = fallback_dir
@@ -45,6 +49,7 @@ class Retrieve(BaseDownload):
         self.temp_dir = temp_dir
         self.save = save
         self.use_saved = use_saved
+        self.prefix = prefix
         if save:
             if use_saved:
                 raise ValueError(
@@ -68,35 +73,41 @@ class Retrieve(BaseDownload):
             return f"{url[:100]}..."
         return url
 
-    @staticmethod
     def get_filename(
+        self,
         url: str,
         filename: Optional[str] = None,
         extensions_from_fn: Tuple[str, ...] = tuple(),
         **kwargs: Any,
-    ) -> str:
+    ) -> Tuple[str, Any]:
+        prefix = kwargs.pop("file_prefix", self.prefix)
+        if prefix:
+            prefix = f"{prefix}_"
         if filename:
-            return filename
-        filename = get_filename_from_url(url)
+            return f"{prefix}{filename}", kwargs
+        filename, extension = get_filename_extension_from_url(
+            url, second_last=True
+        )
+        filename = slugify(filename)
         extensions = list()
-        extension = kwargs.get("format")
-        if extension:
-            extensions.append(extension)
-        extension = kwargs.get("file_type")
-        if extension:
-            extensions.append(extension)
+        format = kwargs.get("format")
+        if format:
+            extensions.append(format)
+        file_type = kwargs.get("file_type")
+        if file_type:
+            extensions.append(file_type)
         if extensions_from_fn:
             extensions.extend(extensions_from_fn)
         if not extensions:
-            return filename
+            return f"{prefix}{filename}{extension}", kwargs
         first_ext = f".{extensions[0].lower()}"
-        _, extension = splitext(filename)
         if not extension:
-            return f"{filename}{first_ext}"
+            return f"{prefix}{filename}{first_ext}", kwargs
         for candidate in extensions:
             if candidate == extension[1:]:
-                return filename
-        return f"{filename}{first_ext}"
+                return f"{prefix}{filename}{extension}", kwargs
+        filename = slugify(f"{filename}{extension}")
+        return f"{prefix}{filename}{first_ext}", kwargs
 
     def download_file(
         self,
@@ -119,7 +130,7 @@ class Retrieve(BaseDownload):
             str: Path to downloaded file
 
         """
-        filename = self.get_filename(url, filename, **kwargs)
+        filename, kwargs = self.get_filename(url, filename, **kwargs)
         if not logstr:
             logstr = filename
         if self.save:
@@ -163,13 +174,13 @@ class Retrieve(BaseDownload):
             filename (Optional[str]): Filename of saved file. Defaults to getting from url.
             logstr (Optional[str]): Text to use in log string to describe download. Defaults to filename.
             fallback (bool): Whether to use static fallback if download fails. Defaults to False.
-            **kwargs: Parameters to pass to download call
+            **kwargs: Parameters to pass to download_text call
 
         Returns:
             str: The text from the file
 
         """
-        filename = self.get_filename(url, filename, **kwargs)
+        filename, kwargs = self.get_filename(url, filename, **kwargs)
         if not logstr:
             logstr = filename
         saved_path = join(self.saved_dir, filename)
@@ -210,13 +221,15 @@ class Retrieve(BaseDownload):
             filename (Optional[str]): Filename of saved file. Defaults to getting from url.
             logstr (Optional[str]): Text to use in log string to describe download. Defaults to filename.
             fallback (bool): Whether to use static fallback if download fails. Defaults to False.
-            **kwargs: Parameters to pass to download call
+            **kwargs: Parameters to pass to download_yaml call
 
         Returns:
             Any: The data from the YAML file
 
         """
-        filename = self.get_filename(url, filename, ("yaml", "yml"), **kwargs)
+        filename, kwargs = self.get_filename(
+            url, filename, ("yaml", "yml"), **kwargs
+        )
         if not logstr:
             logstr = filename
         saved_path = join(self.saved_dir, filename)
@@ -257,13 +270,15 @@ class Retrieve(BaseDownload):
             filename (Optional[str]): Filename of saved file. Defaults to getting from url.
             logstr (Optional[str]): Text to use in log string to describe download. Defaults to filename.
             fallback (bool): Whether to use static fallback if download fails. Defaults to False.
-            **kwargs: Parameters to pass to download call
+            **kwargs: Parameters to pass to download_json call
 
         Returns:
             Any: The data from the JSON file
 
         """
-        filename = self.get_filename(url, filename, ("json",), **kwargs)
+        filename, kwargs = self.get_filename(
+            url, filename, ("json",), **kwargs
+        )
         if not logstr:
             logstr = filename
         saved_path = join(self.saved_dir, filename)
@@ -314,13 +329,14 @@ class Retrieve(BaseDownload):
             filename (Optional[str]): Filename of saved file. Defaults to getting from url.
             logstr (Optional[str]): Text to use in log string to describe download. Defaults to filename.
             fallback (bool): Whether to use static fallback if download fails. Defaults to False.
-            **kwargs: Parameters to pass to download call
+            **kwargs: Parameters to pass to download_file call
 
         Returns:
             Tuple[List[str],Iterator[ListDict]]: Tuple (headers, iterator where each row is a list or dictionary)
 
         """
         path = self.download_file(url, filename, logstr, fallback, **kwargs)
+        kwargs.pop("file_prefix", None)
         return self.downloader.get_tabular_rows(
             path, headers, dict_form, **kwargs
         )
@@ -356,7 +372,12 @@ class Retrieve(BaseDownload):
             if name in ignore:
                 continue
             cls.retrievers[name] = cls(
-                downloader, fallback_dir, saved_dir, temp_dir, save, use_saved
+                downloader,
+                fallback_dir,
+                saved_dir,
+                temp_dir,
+                save,
+                use_saved,
             )
 
     @classmethod
