@@ -39,67 +39,91 @@ class TestRetriever:
         mkdir(temp_dir)
         return saved_dir, temp_dir
 
-    def test_get_filename(self):
-        url = "http://api.worldbank.org/v2/en/indicator/SP.POP.TOTL?downloadformat=excel&dataformat=list"
-        assert Retrieve.get_filename(url) == "SP.POP.TOTL"
-        assert Retrieve.get_filename(url, "hello.xlsx") == "hello.xlsx"
-        assert (
-            Retrieve.get_filename(url, None, format="xlsx")
-            == "SP.POP.TOTL.xlsx"
-        )
-        assert (
-            Retrieve.get_filename(url, None, file_type="xlsx")
-            == "SP.POP.TOTL.xlsx"
-        )
-        assert (
-            Retrieve.get_filename(url, None, ("csv", "xls"))
-            == "SP.POP.TOTL.csv"
-        )
-        assert (
-            Retrieve.get_filename(
-                url, None, ("csv", "xls"), file_type="json", format="xlsx"
-            )
-            == "SP.POP.TOTL.xlsx"
-        )
-        url = "http://api.worldbank.org/v2/en/indicator/SP.POP.TOTL.xlsx?downloadformat=excel&dataformat=list"
-        assert Retrieve.get_filename(url) == "SP.POP.TOTL.xlsx"
-        assert Retrieve.get_filename(url, "hello.xlsx") == "hello.xlsx"
-        assert (
-            Retrieve.get_filename(url, None, format="xlsx")
-            == "SP.POP.TOTL.xlsx"
-        )
-        assert (
-            Retrieve.get_filename(url, None, file_type="xlsx")
-            == "SP.POP.TOTL.xlsx"
-        )
-        assert (
-            Retrieve.get_filename(url, None, ("csv", "xlsx"))
-            == "SP.POP.TOTL.xlsx"
-        )
-        assert (
-            Retrieve.get_filename(
-                url, None, ("csv", "xls"), file_type="json", format="xlsx"
-            )
-            == "SP.POP.TOTL.xlsx"
-        )
-        assert (
-            Retrieve.get_filename(url, None, format="xls")
-            == "SP.POP.TOTL.xlsx.xls"
-        )
-        assert (
-            Retrieve.get_filename(url, None, file_type="xls")
-            == "SP.POP.TOTL.xlsx.xls"
-        )
-        assert (
-            Retrieve.get_filename(url, None, ("csv", "xls"))
-            == "SP.POP.TOTL.xlsx.csv"
-        )
-        assert (
-            Retrieve.get_filename(
-                url, None, ("csv", "xls"), file_type="json", format="xls"
-            )
-            == "SP.POP.TOTL.xlsx.xls"
-        )
+    def test_get_filename(self, dirs, fallback_dir):
+        saved_dir, temp_dir = dirs
+        with Download() as downloader:
+            with Retrieve(
+                downloader,
+                fallback_dir,
+                saved_dir,
+                temp_dir,
+                save=False,
+                use_saved=False,
+                prefix="population",
+            ) as retriever:
+                url = "http://api.worldbank.org/v2/en/indicator/SP.POP.TOTL?downloadformat=excel&dataformat=list"
+                result = retriever.get_filename(url)
+                expected = "population_indicator-sp-pop.TOTL"
+                assert result == (expected, dict())
+                result = retriever.get_filename(url, "hello.xlsx")
+                expected = "population_hello.xlsx"
+                assert result == (expected, dict())
+                result = retriever.get_filename(url, None, format="xlsx")
+                expected = "population_indicator-sp-pop-totl.xlsx"
+                assert result == (expected, {"format": "xlsx"})
+                result = retriever.get_filename(url, None, file_type="xlsx")
+                assert result == (expected, {"file_type": "xlsx"})
+                result = retriever.get_filename(url, None, ("csv", "xls"))
+                expected = "population_indicator-sp-pop-totl.csv"
+                assert result == (expected, dict())
+                result = retriever.get_filename(
+                    url,
+                    None,
+                    ("csv", "xls"),
+                    file_type="json",
+                    format="xlsx",
+                )
+                expected = "population_indicator-sp-pop-totl.xlsx"
+                assert result == (
+                    expected,
+                    {"file_type": "json", "format": "xlsx"},
+                )
+                url = "http://api.worldbank.org/v2/en/indicator/SP.POP.TOTL.xlsx?downloadformat=excel&dataformat=list"
+                result = retriever.get_filename(url)
+                assert result == (expected, dict())
+                result = retriever.get_filename(url, "hello.xlsx")
+                expected = "population_hello.xlsx"
+                assert result == (expected, dict())
+                result = retriever.get_filename(url, None, format="xlsx")
+                expected = "population_indicator-sp-pop-totl.xlsx"
+                assert result == (expected, {"format": "xlsx"})
+                result = retriever.get_filename(url, None, file_type="xlsx")
+                assert result == (expected, {"file_type": "xlsx"})
+                result = retriever.get_filename(url, None, ("csv", "xlsx"))
+                expected = "population_indicator-sp-pop-totl.xlsx"
+                assert result == (expected, dict())
+                result = retriever.get_filename(
+                    url,
+                    None,
+                    ("csv", "xls"),
+                    file_type="json",
+                    format="xlsx",
+                )
+                expected = "population_indicator-sp-pop-totl.xlsx"
+                assert result == (
+                    expected,
+                    {"file_type": "json", "format": "xlsx"},
+                )
+                result = retriever.get_filename(url, None, format="xls")
+                expected = "population_indicator-sp-pop-totl-xlsx.xls"
+                assert result == (expected, {"format": "xls"})
+                result = retriever.get_filename(url, None, file_type="xls")
+                assert result == (expected, {"file_type": "xls"})
+                result = retriever.get_filename(url, None, ("csv", "xls"))
+                expected = "population_indicator-sp-pop-totl-xlsx.csv"
+                assert result == (expected, dict())
+                result = retriever.get_filename(
+                    url,
+                    None,
+                    ("csv", "xls"),
+                    file_type="json",
+                    format="xls",
+                )
+                expected = "population_indicator-sp-pop-totl-xlsx.xls"
+                assert result == (
+                    expected,
+                    {"file_type": "json", "format": "xls"},
+                )
 
     def test_error(self, dirs, retrieverfolder, fallback_dir):
         saved_dir, temp_dir = dirs
